@@ -1,15 +1,15 @@
 def and_(a=True, b=True, c=True, d=True, e=True, f=True, g=True, h=True):
-  """Checks if all values are true. `📘`_
+  """Checks if all values are True. `📘`_
 
   - a: 1st boolean
   - b: 2nd boolean
   - ...
 
   Example:
-    >>> and(true, true)              == true
-    >>> and(true, false)             == false
-    >>> and(true, true, true, true)  == true
-    >>> and(true, false, true, true) == false
+    >>> and_(True, True)              == True
+    >>> and_(True, False)             == False
+    >>> and_(True, True, True, True)  == True
+    >>> and_(True, False, True, True) == False
 
   .. _📘:
     https://github.com/python3f/extra-boolean/wiki/and
